Struct ConfigFile

pub struct ConfigFile<T> { /* private fields */ }
Wrapper around a configuration type T that remembers where it was loaded from and the modification time of the file, and can reload a config if it changed.

Implementations

Source

impl<T: DeserializeOwned + DefaultConfigPath> ConfigFile<T>

pub fn path(&self) -> Option<&Arc<Path>>

Returns None if config was not loaded from a file but provided by the or_else callback of load_config

pub fn perhaps_reload_config(&self) -> Result<Option<Self>>

Check if the file that the config was loaded from has changed, if so, attempt to load it and if successful returns the new instance. Currently only checks the file that it was loaded from for changes; if this config was a default from or_else, no check is done at all. Only parse errors and the file vanishing between checking its metadata and reading it are reported, not stat errors. Only returns a new Self once: updates the internal mtime and if the file doesn’t change again, no new parsing is done.

pub fn load_config( path: Option<Arc<Path>>, or_else: impl FnOnce(&str) -> Result<T>, ) -> Result<Self>

If path is given, the file must exist or an error is returned. Otherwise, a default location is checked (default_config_path_without_suffix) and if a file with one of the fitting file name extensions exists, it is loaded, otherwise or_else is called with a message mentioning what was tried; it can issue an error or generate a default config value.