Trait DefaultConfigPath

pub trait DefaultConfigPath: DeserializeOwned {
    // Required method
    fn default_config_file_name_without_suffix(    ) -> Result<Option<ProperFilename>>;

    // Provided method
    fn default_config_dirs() -> SliceOrBox<'static, ConfigDir> { ... }
}

Required Methods

fn default_config_file_name_without_suffix() -> Result<Option<ProperFilename>>

ConfigFile::load_config tries this file name, together with a list of file name extensions, appended to the paths from default_config_dirs(), and one path is then expected to exist in a dir, if none the next is tried, or its or_else fallback is called. In the case of ConfigDir::Home, a dot is prepended to the file name.

Provided Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors